#ifndef MAIN_H_
#define MAIN_H_

#define DMA_DEV_ID      XPAR_AXIVDMA_0_DEVICE_ID
#define DMA_DEV_1_ID 	XPAR_AXIVDMA_1_DEVICE_ID
#define GPIO_DEV_ID     XPAR_GPIO_0_DEVICE_ID
#define GPIO_DEV_1_ID   XPAR_GPIO_1_DEVICE_ID
#define TIMER_DEV_ID 	XPAR_XTTCPS_1_DEVICE_ID
#define TIMER_IRPT      XPAR_XTTCPS_1_INTR
#define INTC_DEV_ID     XPAR_SCUGIC_SINGLE_DEVICE_ID
#define TTCPS_CLOCK_HZ	XPAR_XTTCPS_0_CLOCK_HZ


#define H_RES        	1280
#define V_RES        	720
#define STRM_WIDTH		3
#define FPS		     	10

#define MEM_BUF_SIZE	(STRM_WIDTH * H_RES * V_RES)
#define DDR_BASE_ADDR   XPAR_DDR_MEM_BASEADDR
#define MEM_BASE_ADDR   (DDR_BASE_ADDR + 0x0A000000)
#define MEM_BASE_R_ADDR (DDR_BASE_ADDR + 0x0B000000)

#define FRAME_W_BASE_1  MEM_BASE_ADDR
#define FRAME_W_BASE_2  (MEM_BASE_ADDR + 0x002A3000)
#define FRAME_W_BASE_3  (MEM_BASE_ADDR + 0x00546000)

#define FRAME_R_BASE_1  MEM_BASE_R_ADDR
#define FRAME_R_BASE_2  (MEM_BASE_R_ADDR + 0x002A3000)
#define FRAME_R_BASE_3  (MEM_BASE_R_ADDR + 0x00546000)


#define FRAME_BUF_SIZE	2
#define FRAME_WORDS     921600
#define FRAME_WORDS_X2  1843200
#define FRAME_WORDS_X3  2764800
#define FRAME_BYTES     (FRAME_WORDS * 4)

#define PNTR_CHANNEL 	1
#define INTR_CHANNEL 	2



#define TIMER_VALUE     ((1000000/FPS) * (COUNTS_PER_SECOND/1000000))



/***************************** WIDI Include Files *********************************/
#include "vdma.h"
#include "timer_intr.h"
#include "network_init.h"
#include "frame_mem_config.h"


/***************************** XILINX Include Files *********************************/
#include "xaxivdma.h"
#include "xparameters.h"
#include "xdebug.h"
#include "xil_printf.h"
#include "sleep.h"
#include "xil_io.h"
#include "xil_mem.h"
#include "xil_cache.h"
#include "xgpio.h"
#include "xtime_l.h"
#include "xscutimer.h"
#include "xscugic.h"
#include "lwip/mem.h"

/************************** Variable Definitions *****************************/
u32 testFrame[FRAME_BUF_SIZE][FRAME_WORDS_X3];
int FrameReadyFlag;
int FrameBufferNum;


/************************** Function Prototypes ******************************/
int  RxConfig(void);
int  grayCode(u32 n);
void IRQHanlder(void *CallBackRef);
void ReadMem(u32 *Addr, u32 Words);
void WriteMem(u32 *Addr, u32 Words, u32 Data);

#endif  /* MAIN_H_ */ 
